@@ -372,11 +372,26 @@ def import_from_path(path: str, name: str, module_name: str = '.') -> Any:
 		if name in module.__dict__:
 			return module.__dict__[name]
 
-def run_notebook(path: str, timeout: int = 600, kernel_name: str = 'python3') -> Any:
+def run_notebook(path: str) -> None:
 	''' Runs a notebook and returns the result. '''
-	from nbformat import read, NO_CONVERT
-	from nbconvert.preprocessors import ExecutePreprocessor
-	with open(path) as fp:
-		data = read(fp, NO_CONVERT)
-	ep = ExecutePreprocessor(timeout=timeout, kernel_name=kernel_name)
-	return ep.preprocess(data)
\ No newline at end of file
+	source = ''
+	for cell in load(path, 'json')['cells']:
+		if cell['cell_type'] == 'code':
+			source += ''.join(line for line in cell['source'] if not line.startswith('%')) + '\n'
+	return exec(source, globals(), locals())
+
+def already_running(path_pidfile: str = 'pid.txt') -> bool:
+	''' Uses a PID file to check if an instance of this script is already running. If it's
+	not running, it will create a PID file (a file with the PID of the current process). '''
+	from os import getpid
+	from os.path import exists
+	from psutil import pid_exists, Process
+	my_pid = getpid()
+	try:
+		assert exists(path_pidfile)
+		pid = int(load(path_pidfile))
+		assert pid_exists(pid) and Process(pid).cmdline() == Process(my_pid).cmdline()
+		return True
+	except:
+		save(path_pidfile, str(my_pid))
+	return False
\ No newline at end of file
